we just created two skills for architecture diagram, why not let's play with it.
use it to draw a application module diagram and application landscape diagram

- collect all the info you need to do it